==> gitlab-foss-v18.6.2.tar.bz2: gitlab-foss-v18.6.2/spec/lib/bulk_imports/projects/graphql/get_snippet_repository_query_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe BulkImports::Projects::Graphql::GetSnippetRepositoryQuery, feature_category: :importers do
  let_it_be(:entity) { create(:bulk_import_entity) }
  let_it_be(:tracker) { create(:bulk_import_tracker, entity: entity) }
  let_it_be(:context) { BulkImports::Pipeline::Context.new(tracker) }

  subject(:query) { described_class.new(context: context) }

  context 'with quarantine', quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/546526' do
    it_behaves_like 'a valid Direct Transfer GraphQL query'
  end

  it 'returns snippet httpUrlToRepo' do
    expect(subject.to_s).to include('httpUrlToRepo')
  end

  it 'returns snippet createdAt' do
    expect(subject.to_s).to include('createdAt')
  end

  it 'returns snippet title' do
    expect(subject.to_s).to include('title')
  end

  describe '.variables' do
    it 'queries project based on source_full_path and pagination' do
      expected = { full_path: entity.source_full_path, cursor: nil, per_page: 500 }

      expect(subject.variables).to eq(expected)
    end
  end

  describe '.data_path' do
    it '.data_path returns data path' do
      expected = %w[data project snippets nodes]

      expect(subject.data_path).to eq(expected)
    end
  end

  describe '.page_info_path' do
    it '.page_info_path returns pagination information path' do
      expected = %w[data project snippets page_info]

      expect(subject.page_info_path).to eq(expected)
    end
  end
end

==> gitlab-foss-v18.8.3.tar.bz2: gitlab-foss-v18.8.3/spec/lib/bulk_imports/projects/graphql/get_snippet_repository_query_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe BulkImports::Projects::Graphql::GetSnippetRepositoryQuery, feature_category: :importers do
  let_it_be(:entity) { create(:bulk_import_entity) }
  let_it_be(:tracker) { create(:bulk_import_tracker, entity: entity) }
  let_it_be(:context) { BulkImports::Pipeline::Context.new(tracker) }

  subject(:query) { described_class.new(context: context) }

  context 'with quarantine', quarantine: 'https://gitlab.com/gitlab-org/quality/test-failure-issues/-/issues/9381' do
    it_behaves_like 'a valid Direct Transfer GraphQL query'
  end

  it 'returns snippet httpUrlToRepo' do
    expect(subject.to_s).to include('httpUrlToRepo')
  end

  it 'returns snippet createdAt' do
    expect(subject.to_s).to include('createdAt')
  end

  it 'returns snippet title' do
    expect(subject.to_s).to include('title')
  end

  describe '.variables' do
    it 'queries project based on source_full_path and pagination' do
      expected = { full_path: entity.source_full_path, cursor: nil, per_page: 500 }

      expect(subject.variables).to eq(expected)
    end
  end

  describe '.data_path' do
    it '.data_path returns data path' do
      expected = %w[data project snippets nodes]

      expect(subject.data_path).to eq(expected)
    end
  end

  describe '.page_info_path' do
    it '.page_info_path returns pagination information path' do
      expected = %w[data project snippets page_info]

      expect(subject.page_info_path).to eq(expected)
    end
  end
end
